==> extended-log-debug-1.2.0.1-0-x86_64.pkg.tar.zst: usr/src/debug/extended-log/Extended-Log-1.2.0.1/src/LogEntry.cpp <==
#include "EntryType.hpp"
#include "LogEntry.hpp"

#include <QDateTime>
#include <QString>

ExtendedLog::LogEntry::LogEntry(EntryType type, QString message) :
	message(message),
	dateTime(QDateTime::currentDateTime())
{
	this->type = type;
}

ExtendedLog::LogEntry::LogEntry(QString dateTime, QString type, QString message) :
	dateTime(QDateTime::fromString(dateTime, "dd.MM.yyyy hh:mm:ss")),
	message(message)
{
	this->type = getEntryType(type);
}

ExtendedLog::LogEntry::LogEntry(const LogEntry &other)
{
	*this = other;
}

ExtendedLog::LogEntry& ExtendedLog::LogEntry::operator=(const ExtendedLog::LogEntry &other)
{
	this->dateTime = other.dateTime;
	this->message = other.message;
	this->type = other.type;
	return *this;
}

QString ExtendedLog::LogEntry::toString()
{
	QString value = this->dateTime.toString("dd.MM.yyyy hh:mm:ss")
					+ " : "
					+ this->typeString()
					+ " : "
					+ this->message;
	return value;
}

ExtendedLog::EntryType ExtendedLog::LogEntry::getEntryType()
{
	return this->type;
}

QString ExtendedLog::LogEntry::typeString()
{
	return entryTypeToString();
}

void ExtendedLog::LogEntry::setEntryType(QString value)
{
	this->type = getEntryType(value);
}

ExtendedLog::EntryType ExtendedLog::LogEntry::getEntryType(QString typeString)
{
	if (typeString == "Information") { return EntryType::INFORMATION; }
	else if (typeString == "Warning") { return EntryType::WARNING; }
	else if (typeString == "Error") { return EntryType::ERROR; }
	else { return EntryType::UNKNOWN; }
}

QString ExtendedLog::LogEntry::entryTypeToString()
{
	switch (this->type)
	{
		case EntryType::INFORMATION:
			return "Information";
		case EntryType::WARNING:
			return "Warning";
		case EntryType::ERROR:
			return "Error";
		case EntryType::UNKNOWN:
		default:
			return "Unknown";
	}
}

QDateTime& ExtendedLog::LogEntry::getDateTime()
{
	return this->dateTime;
}

QString& ExtendedLog::LogEntry::getMessage()
{
	return this->message;
}

bool ExtendedLog::LogEntry::trySetDateTime(QString value)
{
	QDateTime timestamp = QDateTime::fromString(value, "dd.MM.yyyy hh:mm:ss");
	if (timestamp.isValid())
	{
		this->dateTime = timestamp;
		return true;
	}
	else
	{
		this->dateTime = QDateTime::currentDateTime();
		return false;
	}
}

==> extended-log-debug-1.2.0.3-0-x86_64.pkg.tar.zst: usr/src/debug/extended-log/Extended-Log-1.2.0.3/src/LogEntry.cpp <==
#include "EntryType.hpp"
#include "LogEntry.hpp"

#include <QDateTime>
#include <QString>

ExtendedLog::LogEntry::LogEntry(EntryType type, QString message) :
	dateTime(QDateTime::currentDateTime()),
	message(message)
{
	this->type = type;
}

ExtendedLog::LogEntry::LogEntry(QString dateTime, QString type, QString message) :
	dateTime(QDateTime::fromString(dateTime, "dd.MM.yyyy hh:mm:ss")),
	message(message)
{
	this->type = getEntryType(type);
}

ExtendedLog::LogEntry::LogEntry(const LogEntry &other)
{
	*this = other;
}

ExtendedLog::LogEntry& ExtendedLog::LogEntry::operator=(const ExtendedLog::LogEntry &other)
{
	this->dateTime = other.dateTime;
	this->message = other.message;
	this->type = other.type;
	return *this;
}

QString ExtendedLog::LogEntry::toString()
{
	QString value = this->dateTime.toString("dd.MM.yyyy hh:mm:ss")
					+ " : "
					+ this->typeString()
					+ " : "
					+ this->message;
	return value;
}

ExtendedLog::EntryType ExtendedLog::LogEntry::getEntryType()
{
	return this->type;
}

QString ExtendedLog::LogEntry::typeString()
{
	return entryTypeToString();
}

void ExtendedLog::LogEntry::setEntryType(QString value)
{
	this->type = getEntryType(value);
}

ExtendedLog::EntryType ExtendedLog::LogEntry::getEntryType(QString typeString)
{
	if (typeString == "Information") { return EntryType::INFORMATION; }
	else if (typeString == "Warning") { return EntryType::WARNING; }
	else if (typeString == "Error") { return EntryType::ERROR; }
	else { return EntryType::UNKNOWN; }
}

QString ExtendedLog::LogEntry::entryTypeToString()
{
	switch (this->type)
	{
		case EntryType::INFORMATION:
			return "Information";
		case EntryType::WARNING:
			return "Warning";
		case EntryType::ERROR:
			return "Error";
		case EntryType::UNKNOWN:
		default:
			return "Unknown";
	}
}

QDateTime& ExtendedLog::LogEntry::getDateTime()
{
	return this->dateTime;
}

QString& ExtendedLog::LogEntry::getMessage()
{
	return this->message;
}

bool ExtendedLog::LogEntry::trySetDateTime(QString value)
{
	QDateTime timestamp = QDateTime::fromString(value, "dd.MM.yyyy hh:mm:ss");
	if (timestamp.isValid())
	{
		this->dateTime = timestamp;
		return true;
	}
	else
	{
		this->dateTime = QDateTime::currentDateTime();
		return false;
	}
}
